
"""
Usage:
    cbr-qualifier disk --help
    cbr-qualifier disk [--config=config.yml] --list
    cbr-qualifier disk [--config=config.yml] [--profile=PROFILE] --list_tests
    cbr-qualifier disk --get_config
    cbr-qualifier disk [--verbose] --print_output <output.yml>
    cbr-qualifier disk [--config=config.yml] [--factor=FACTOR]
         [--runtime=RUNTIME] [--filesize=FILESIZE] [--profile=PROFILE]
         [--test=TEST] [--output=output.yml] [--multiplier=MULTIPLIER]
         [--no_delete] [--verbose] <test_directory>

Options
    -h, --help
    -c config.file --config=confg.yml   Disk Test Config File
    -f factor --factor=FACTOR           Fudge factor (Match to factor percent of thresholds)
    -r runtime --runtime=RUNTIME        Override runtime in profile
    -s filesize --filesize=FILESIZE     Override filesize in profile
    -p profile --profile=PROFILE        Specify Profile
    -l --list                           List IO profiles
    -T --list_tests                     List IO tests
    -n --no_delete                      Do not delete fio test file
    -t test --test=TEST                 Run a Specific Test
    -g --get_config                     Get the default config file yaml
    -o --output=output.yml              Write output in yaml to file
    -m --multiplier=MULTIPLIER          Multiplier on test profile, most useful with the per_million_process_doc profile
    -v --verbose                        Verbose mode, prints IOPS numbers
    -P --print_output                   Pretty print results from a output.yml file
"""
import sys
from docopt import docopt
from cbr_qualifier.disk.test import TestRunner


def main(argv):
    """ Execute based on docopt options

    :param argv: Arguments from man program
    """
    options = docopt(__doc__, argv=argv)
    if options['--list']:
        TestRunner.print_profiles(conf_file=options['--config'])
        exit(0)
    elif options['--list_tests']:
        TestRunner.print_tests(conf_file=options['--config'], run_config=options['--profile'])
        exit(0)
    elif options['--get_config']:
        TestRunner.print_default_config_yaml()
        exit(0)
    elif options['--print_output']:
        TestRunner.print_results(verbose=options['--verbose'], results_file=options['<output.yml>'])
        exit(0)
    else:
        runner = TestRunner(options['<test_directory>'], conf_file=options['--config'], runtime=options['--runtime'],
                            close_enough_factor=options['--factor'], profile=options['--profile'],
                            multiplier=options['--multiplier'], filesize=options['--filesize'])
        if options['--test']:
            results = [runner.run_test(options['--test'])]
        else:
            results = runner.run()
        if options['--output']:
            runner.write_results(results, options['--output'])
        else:
            runner.print_results(results=results, verbose=options['--verbose'])
        if not options['--no_delete']:
            runner.delete_testfile()


if __name__ == '__main__':
    main(sys.argv)
